/*******************************************************************************
 *
 * Copyright (c) 2016-2026 HYCON Technology, Inc.
 * All rights reserved.
 * HYCON Technology <www.hycontek.com>
 *
 * HYCON reserves the right to amend this code without notice at any time.
 * HYCON assumes no responsibility for any errors appeared in the code,
 * and HYCON disclaims any express or implied warranty, relating to sale
 * and/or use of this code including liability or warranties relating
 * to fitness for a particular purpose, or infringement of any patent,
 * copyright or other intellectual property right.
 *
 * -----------------------------------------------------------------------------
 * Project Name : HY16F3981_ADC_IA
 * IDE tooling  : AndeSight C/C++ IDE, version: 2.1.1 Build ID : 201608241332
 * Device Ver.  : HY16F_RDSp3_DeviceV0.2 crt0.o for HY16F3981 MCU.
 * Library Ver. : 0.2
 * MCU Device   :
 * Description  : Showing high 16 bit ADCData on LCD display
 * Created Date : 2018/3/9
 * Created by   : Robert.Wang
 *
 * Program Description:
 * --------------------
 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include "DrvCLOCK.h"
#include "Display.h"
#include "my define.h"
#include "HY16F3981.h"
#include "System.h"
#include "DrvADC.h"
#include "DrvPMU.h"
#include "DrvIA.h"
/*----------------------------------------------------------------------------*/
/* STRUCTURES                                                                 */
/*----------------------------------------------------------------------------*/
volatile typedef union _MCUSTATUS
{
  char  _byte;
  struct
  {
    unsigned b_ADCdone:1;
    unsigned b_TMAdone:1;
    unsigned b_TMBdone:1;
    unsigned b_TMC0done:1;
    unsigned b_TMC1done:1;
    unsigned b_RTCdone:1;
    unsigned b_UART_TxDone:1;
    unsigned b_UART_RxDone:1;
  };
} MCUSTATUS;

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
//#define HAO_2MHZ
#define HAO_4MHZ
//#define HAO_10MHZ
//#define HAO_16MHZ
#define SW_IA_ADC_Chopper
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
MCUSTATUS  MCUSTATUSbits;
int ADCData;
int ADCData_Array[2];
int ADCData_Chopper;
char i;
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num);
void InitalADC(void);
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
int main(void)
{
  InitalADC();
  DisplayInit();
  ClearLCDframe();
  Delay(10000);
  DisplayHYcon();
  Delay(10000);
  SYS_EnableGIE(4,0x3FF);              //Enable GIE(Global Interrupt)

  MCUSTATUSbits._byte = 0;

  while(1)
  {
#if defined(SW_IA_ADC_Chopper)
    for(i=0;i<=1;i++)
    {
      switch (i)
      {
        case 0:
        while(MCUSTATUSbits.b_ADCdone==0);
        MCUSTATUSbits.b_ADCdone=0;
        DrvADC_SetADCInputChannel(IA_Input_AIO0,IA_Input_AIO1);
        DrvADC_CombFilter(DISABLE);
        DrvADC_CombFilter(ENABLE);
        MCUSTATUSbits.b_ADCdone=0;
        while(MCUSTATUSbits.b_ADCdone==0);
        ADCData_Array[0]=ADCData>>16;
        MCUSTATUSbits.b_ADCdone=0;
        break;

        case 1:
        DrvADC_SetADCInputChannel(IA_Input_AIO1,IA_Input_AIO0);
        DrvADC_CombFilter(DISABLE);
        DrvADC_CombFilter(ENABLE);
        MCUSTATUSbits.b_ADCdone=0;
        while(MCUSTATUSbits.b_ADCdone==0);
        ADCData_Array[1]=ADCData>>16;
        ADCData_Chopper=(ADCData_Array[0]-ADCData_Array[1])>>1;
        LCD_DATA_DISPLAY(ADCData_Chopper);
        MCUSTATUSbits.b_ADCdone=0;
        break;
      }
    }
#else  //HW IA_ADC_Chopper mode

    if(MCUSTATUSbits.b_ADCdone)
    {
      LCD_DATA_DISPLAY(ADCData>>16);   //16bits give up.
      MCUSTATUSbits.b_ADCdone=0;
    }
#endif
  }
  return 0;
}
/*----------------------------------------------------------------------------*/
/* Function Name: HW0_ISR()                                                   */
/* Description  : I2C/UART/SPI interrupt Service Routine (HW0).               */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW0_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW1_ISR()                                                   */
/* Description  : WDT & RTC & Timer A/B/C interrupt Service Routine (HW1).    */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW1_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW2_ISR()                                                   */
/* Description  : ADC interrupt Service Routine (HW2).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW2_ISR(void)
{
  if(DrvADC_ReadIntFlag())             //Read ADC Flag
  {
	ADCData=DrvADC_GetConversionData();
	MCUSTATUSbits.b_ADCdone=1;
  }
}
/*----------------------------------------------------------------------------*/
/* Function Name: HW4_ISR()                                                   */
/* Description  : PT3 interrupt Service Routine (HW4).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW4_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW5_ISR()                                                   */
/* Description  : PT2 interrupt Service Routine (HW5).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW5_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW7_ISR()                                                   */
/* Description  : UART2 interrupt Service Routine (HW7).                      */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW7_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW8_ISR()                                                   */
/* Description  : TMB2 interrupt Service Routine (HW8).                       */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW8_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW9_ISR()                                                   */
/* Description  : OPA interrupt Service Routine (HW9).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW9_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: tlb_exception_handler()                                     */
/* Description  : Exception Service Routines.                                 */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void tlb_exception_handler()
{
  asm("nop");  //procedure define by customer.
  asm("nop");
}


/*----------------------------------------------------------------------------*/
/* Function Name: InitalADC()                                                 */
/* Description  : ADC Initialization Subroutines.                             */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void InitalADC(void)
{
  //Set ADC Clock
#if defined(HAO_2MHZ)
  DrvCLOCK_EnableHighOSC(E_INTERNAL,10);   //Select HSRC
  DrvCLOCK_SelectIHOSC(0);                 //Select internal 2MHZ=HS_CK
  DrvADC_ClkEnable(2);                     //Setting ADC CLOCK ADCK=HS_CK/4
#endif
#if defined(HAO_4MHZ)
  DrvCLOCK_EnableHighOSC(E_INTERNAL,10);   //Select HSRC
  DrvCLOCK_SelectIHOSC(1);                 //Select internal 4MHZ=HS_CK
  DrvADC_ClkEnable(2);                     //Setting ADC CLOCK ADCK=HS_CK/4
#endif
#if defined(HAO_10MHZ)
  DrvCLOCK_EnableHighOSC(E_INTERNAL,10);   //Select HSRC
  DrvCLOCK_SelectIHOSC(2);                 //Select internal 10MHZ=HS_CK
  DrvADC_ClkEnable(3);                     //Setting ADC CLOCK ADCK=HS_CK/8
#endif
#if defined(HAO_16MHZ)
  DrvCLOCK_EnableHighOSC(E_INTERNAL,10);   //Select HSRC
  DrvCLOCK_SelectIHOSC(3);                 //Select internal 16MHZ=HS_CK
  DrvADC_ClkEnable(4);                     //Setting ADC CLOCK ADCK=HS_CK/16
#endif

  //Set VDDA voltage
  DrvPMU_VDDA_LDO_Ctrl(E_LDO);
  DrvPMU_VDDA_Voltage(E_VDDA2_4);
  DrvPMU_BandgapEnable();
  DrvPMU_REFO_Enable();
  Delay(0x1000);
  DrvPMU_AnalogGround(ENABLE);             //ADC analog ground source selection.
                                           //1 : Enable buffer and use internal source(need to work with ADC)

  //Set IA
  DrvIA_SetIAInputChannel(IA_Input_AIO0,IA_Input_AIO1);  //ADC positive=AIO0, negative=AIO1
  DrvIA_IAGain(IA_IAGain_4);               //IA Gain=4
#if defined(SW_IA_ADC_Chopper)
  DrvIA_IACHM(IA_IACHM_NoChopper);         //IA Chopper Off
#else  //HW IA_ADC_Chopper mode
  DrvIA_IACHM(IA_IACHM_Both);              //IA Chopper On
#endif
  DrvIA_IAIS(0);                           //Input control=open
  DrvIA_ENIA(0);                           //Disable IA
  DrvIA_ENIA(1);                           //Enable IA

  //Set ADC input pin
  DrvADC_SetADCInputChannel(OP_OP,OP_ON);  //Set the ADC positive/negative input voltage source.
  DrvADC_InputSwitch(OPEN);                //ADC signal input (positive and negative) short(VISHR) control.
  DrvADC_RefInputShort(OPEN);              //Set the ADC reference input (positive and negative) short(VRSHR) control.
  DrvADC_ADGain(0);                        //ADC Gain=1
  DrvADC_DCoffset(0);                      //DC offset input voltage selection (VREF=REFP-REFN)
  DrvADC_RefVoltage(0,0);                  //Set the ADC reference voltage. VDDA-VSSA
  DrvADC_FullRefRange(1);                  //Set the ADC full reference range select.
                                           //0: Full reference range input
                                           //1: 1/2 reference range input
  DrvADC_OSR(0);                           //0 : OSR=32768

  //Set ADC interrupt
  DrvADC_EnableInt();
  DrvADC_Enable();
  DrvADC_CombFilter(ENABLE);               //Enable comb filter

}

/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
  for(;num>0;num--)
  asm("NOP");
}
/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
