/*******************************************************************************
 *
 * Copyright (c) 2016-2026 HYCON Technology, Inc.
 * All rights reserved.
 * HYCON Technology <www.hycontek.com>
 *
 * HYCON reserves the right to amend this code without notice at any time.
 * HYCON assumes no responsibility for any errors appeared in the code,
 * and HYCON disclaims any express or implied warranty, relating to sale
 * and/or use of this code including liability or warranties relating
 * to fitness for a particular purpose, or infringement of any patent,
 * copyright or other intellectual property right.
 *
 * -----------------------------------------------------------------------------
 * Project Name : HY16F3981_DAC
 * IDE tooling  : AndeSight C/C++ IDE, version: 2.1.1 Build ID : 201608241332
 * Device Ver.  : HY16F_RDSp3_DeviceV0.2 crt0.o for HY16F3981 MCU.
 * Library Ver. : 0.2
 * MCU Device   :
 * Description  : HY16F3981 12bit DAC output voltage from stage 0 to 4095
 * Created Date : 2018/3/9
 * Created by   : Robert.Wang
 *
 * Program Description:
 * --------------------
 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include "Display.h"
#include "my define.h"
#include "HY16F3981.h"
#include "DrvDAC.h"
#include "DrvPMU.h"
/*----------------------------------------------------------------------------*/
/* STRUCTURES                                                                 */
/*----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num);

/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
int main(void)
{
  unsigned char i;

  //Set Power system
  DrvPMU_VDDA_LDO_Ctrl(E_LDO);             //LDO ON
  DrvPMU_VDDA_Voltage(E_VDDA2_4);          //VDDA=2.4

  //Set DAC
  DrvDAC_Open(E_DAC_PVDDA,E_DAC_NVSSA,0);  //DAC_Vrefp= VDDA, DAC_Vrefn= VSSA, DAO=0
  DrvDAC_DALH(1);                          //Set DALH=1b
  DrvDAC_EnableOutput();                   //Enable 12-bit resistance ladder DAC output
  DrvDAC_Enable();                         //Enable 12-bit resistance ladder DAC function

  while(1)
  {
    for(i=0;i<4096;i++)
    {
      DrvDAC_DABIT(i);
      Delay(1000);                         //Delay for reference
	  //User can use meter to check the pin14(DAO) to pin2(VSS) to check the DAC output voltage
    }
  }
  return 0;
}

/*----------------------------------------------------------------------------*/
/* Function Name: HW0_ISR()                                                   */
/* Description  : I2C/UART/SPI interrupt Service Routine (HW0).               */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW0_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW1_ISR()                                                   */
/* Description  : WDT & RTC & Timer A/B/C interrupt Service Routine (HW1).    */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW1_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW2_ISR()                                                   */
/* Description  : ADC interrupt Service Routine (HW2).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW2_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW4_ISR()                                                   */
/* Description  : PT3 interrupt Service Routine (HW4).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW4_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW5_ISR()                                                   */
/* Description  : PT2 interrupt Service Routine (HW5).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW5_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW7_ISR()                                                   */
/* Description  : UART2 interrupt Service Routine (HW7).                      */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW7_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW8_ISR()                                                   */
/* Description  : TMB2 interrupt Service Routine (HW8).                       */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW8_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: HW9_ISR()                                                   */
/* Description  : OPA interrupt Service Routine (HW9).                        */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void HW9_ISR(void)
{

}
/*----------------------------------------------------------------------------*/
/* Function Name: tlb_exception_handler()                                     */
/* Description  : Exception Service Routines.                                 */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void tlb_exception_handler()
{
  asm("nop");  //procedure define by customer.
  asm("nop");
}
/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
  for(;num>0;num--)
  asm("NOP");
}
/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
