/*******************************************************************************
 *
 * Copyright (c) 2016-2026 HYCON Technology, Inc.
 * All rights reserved.
 * HYCON Technology <www.hycontek.com>
 *
 * HYCON reserves the right to amend this code without notice at any time.
 * HYCON assumes no responsibility for any errors appeared in the code,
 * and HYCON disclaims any express or implied warranty, relating to sale
 * and/or use of this code including liability or warranties relating
 * to fitness for a particular purpose, or infringement of any patent,
 * copyright or other intellectual property right.
 *
 * -----------------------------------------------------------------------------
 * Project Name :
 * IDE tooling  :
 * Device Ver.  :
 * Library Ver. :
 * MCU Device   :
 * Description  :
 * Created Date : 2018/2/18
 * Created by   :
 *
 * Program Description:
 *
 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include "DrvI2C.h"
#include "EEPROM_24Cxx.h"

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
#define  I2CBufferSize  256
#define  EPROMSIZE 2
//EEPROM Device address (If 7 bits, Lsb bit is don't care)
#define  EEPROM_ADDR    0xA0           // Device address for slave target
                                       // Note: This address is specified
                                       // in the Microchip 24LC02B datasheet.
#define I2C_WRITE   0x00               // I2C WRITE command
#define I2C_READ    0x01               // I2C READ command
#define I2C_Delay   1000000            //HAO=2MHz, wait 5s
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
extern unsigned char I2C_RW;
extern unsigned char I2C_TARGET;   // Target I2C slave address
extern unsigned char I2C_Sendbuf[I2CBufferSize];
extern unsigned char I2C_Recbuf[I2CBufferSize];
extern unsigned int I2C_DataTxLen,I2C_DataTxIndex,I2C_DataRxLen,I2C_DataRxIndex;
extern unsigned char I2C_EndFlag;
unsigned int I2C_Timeout;
//EPROMSIZE=2=>2kBit(2048)=24c02,
//EPROMSIZE=4=>4kBit(4096)=24c04,
//EPROMSIZE=32=>32kBit(32768)=24c32,
//EPROMSIZE=512=>512kBit(524288)=24c512

/*----------------------------------------------------------------------------*/
/* EEPROM_ByteWrite ()                                                        */
/*                                                                            */
/* Return Value : None                                                        */
/* Parameters   :                                                             */
/* 1) unsigned int addr - address to I2C_WRITE in the EEPROM                  */
/*                                                                            */
/* 2) unsigned char dat-data to I2C_WRITE to the address <addr> in the EEPROM */
/*                        range is full range of character: 0 to 255          */
/*                                                                            */
/* This function writes the value in <dat> to location <addr> in the EEPROM   */
/* then polls the EEPROM until the I2C_WRITE is complete.                     */
/*                                                                            */
/*----------------------------------------------------------------------------*/
void EEPROM_ByteWrite(unsigned int addr, unsigned char dat)
{
#if ((EPROMSIZE > 2)&&(EPROMSIZE <= 32))
  I2C_TARGET  = EEPROM_ADDR|((addr>>7)&0x0E);  //Device_ID_Addr=0XA0
#elif (EPROMSIZE > 512)
  I2C_TARGET  = EEPROM_ADDR|((addr>>15)&0x0E);  //Device_ID_Addr=0XA0
#else
  I2C_TARGET  = EEPROM_ADDR;   //Device_ID_Addr=0XA0
#endif

#if (EPROMSIZE <= 32)
  I2C_Sendbuf[0]  = (addr&0xFF);  //24Cxx Memory Address
  I2C_Sendbuf[1]  = dat;          //24Cxx Memory Data
  I2C_DataTxLen=2;
#else
  I2C_Sendbuf[0]  = ((addr>>8)&0xFF);  //24Cxx Memory Address
  I2C_Sendbuf[1]  = (addr&0xFF);  //24Cxx Memory Address
  I2C_Sendbuf[2]  = dat;          //24Cxx Memory Data
  I2C_DataTxLen=3;
#endif
  I2C_Timeout=I2C_Delay;  //HAO=2MHz, wait 5s
  I2C_DataTxIndex=0;
  I2C_EndFlag=0;
  I2C_RW = I2C_WRITE;
  DrvI2C_Ctrl(1,0,0,0);  // I2C as master sends START signal
  if(I2C_EndFlag == 0)  // Wait I2C Tx Finish
  {
    while((I2C_Timeout != 0) && (I2C_EndFlag==0) )
    {
	  I2C_Timeout--;
	  asm("nop");
    }
  }

}

/*----------------------------------------------------------------------------*/
/* EEPROM_ByteRead ()                                                         */
/*----------------------------------------------------------------------------*/
unsigned char EEPROM_ByteRead(unsigned int addr)
{
  unsigned char retval;               // Holds the return value

#if ((EPROMSIZE > 2)&&(EPROMSIZE <= 32))
  I2C_TARGET  = EEPROM_ADDR|((addr>>7)&0x0E);  //Device_ID_Addr=0XA0
#elif (EPROMSIZE > 512)
  I2C_TARGET  = EEPROM_ADDR|((addr>>15)&0x0E);  //Device_ID_Addr=0XA0
#else
  I2C_TARGET  = EEPROM_ADDR;  //Device_ID_Addr=0XA0
#endif

#if (EPROMSIZE <= 32)
  I2C_Sendbuf[0]  = (addr&0xFF);  //24Cxx Memory Address
  I2C_DataTxLen=1;
#else
  I2C_Sendbuf[0]  = ((addr>>8)&0xFF);  //24Cxx Memory Address
  I2C_Sendbuf[1]  = (addr&0xFF);  //24Cxx Memory Address
  I2C_DataTxLen=2;
#endif
  I2C_Timeout=I2C_Delay;  //HAO=2MHz, wait 5s
  I2C_DataTxIndex=0;
  I2C_DataRxLen=1;
  I2C_DataRxIndex=0;
  I2C_EndFlag=0;
  I2C_RW = I2C_READ;
  DrvI2C_Ctrl(1,0,0,0);  // I2C as master sends START signal
  if(I2C_EndFlag == 0)  // Wait I2C Tx Finish
  {
    while((I2C_Timeout != 0) && (I2C_EndFlag==0) )
    {
	  I2C_Timeout--;
	  asm("nop");
    }
  }


  retval=I2C_Recbuf[0];
  return retval;
}
/*----------------------------------------------------------------------------*/
/* EEPROM_WriteArray()                                                        */
/*----------------------------------------------------------------------------*/
/* Return Value : None                                                        */
/* Parameters   :                                                             */
/* 1) unsigned int dest_addr-beginning address to I2C_WRITE to in the EEPROM  */
/* 2) unsigned char* src_addr - pointer to the array of data to be written    */
/*                        range is full range of character: 0 to 255          */
/* 3) unsigned int len - length of the array to be written to the EEPROM      */
/* Writes <len> data bytes to the EEPROM slave specified by the <EEPROM_ADDR> */
/* constant.                                                                  */
/*----------------------------------------------------------------------------*/
void EEPROM_WriteArray(unsigned int dest_addr, unsigned char* src_addr, unsigned int len)
{
  unsigned char* pData = (unsigned char*) src_addr;
  unsigned int WCount,DelayT;

  for( WCount = 0; WCount < len; WCount++ )
  {
    EEPROM_ByteWrite(dest_addr++, *pData++);
    for(DelayT=1000;DelayT>0;DelayT--)
    asm("NOP");
  }
}
/*----------------------------------------------------------------------------*/
/* EEPROM_WriteArray2()                                                       */
/*----------------------------------------------------------------------------*/
/* Return Value : None                                                        */
/* Parameters   :                                                             */
/* 1) unsigned int dest_addr-beginning address to I2C_WRITE to in the EEPROM  */
/* 2) unsigned char* src_addr - pointer to the array of data to be written    */
/*                        range is full range of character: 0 to 255          */
/* 3) unsigned int len - length of the array to be written to the EEPROM      */
/* Writes <len> data bytes to the EEPROM slave specified by the <EEPROM_ADDR> */
/* constant.                                                                  */
/*----------------------------------------------------------------------------*/
void EEPROM_WriteArray2(unsigned int dest_addr, unsigned char* src_addr, unsigned int len)
{
  unsigned char* pData = (unsigned char*) src_addr;
  unsigned int WCount;

  I2C_TARGET  = EEPROM_ADDR;
  I2C_Sendbuf[0]  = (dest_addr&0xFF);
  I2C_DataTxLen=1;

  for(WCount=0 ; WCount<len; WCount++)
  {
    I2C_Sendbuf[I2C_DataTxLen++]=*pData;
    pData++;
  }
  I2C_Timeout=I2C_Delay;  //HAO=2MHz, wait 5s
  I2C_DataTxIndex=0;
  I2C_EndFlag=0;
  I2C_RW = I2C_WRITE;
  DrvI2C_Ctrl(1,0,0,0);  // I2C as master sends START signal
  asm("NOP");
  if(I2C_EndFlag == 0)  // Wait I2C Tx Finish
  {
    while((I2C_Timeout != 0) && (I2C_EndFlag==0) )
    {
	  I2C_Timeout--;
	  asm("nop");
    }
  }

}


/*----------------------------------------------------------------------------*/
/* EEPROM_ReadArray ()                                                        */
/*----------------------------------------------------------------------------*/
/* Return Value : None                                                        */
/* Parameters   :                                                             */
/*   1) unsigned char* dest_addr - pointer to the array that will be filled   */
/*                                 with the data from the EEPROM              */
/*                        range is full range of character: 0 to 255          */
/* 2)unsigned int src_addr-beginning address to I2C_READ data from the EEPROM */
/* 3)unsigned int len - length of the array to be I2C_READ from the EEPROM    */
/* Reads up to 256 data bytes from the EEPROM slave specified by the          */
/* <EEPROM_ADDR> constant.                                                    */
/*----------------------------------------------------------------------------*/
void EEPROM_ReadArray (unsigned char* dest_addr, unsigned int src_addr,
                       unsigned int len)
{
  unsigned char* pData = (unsigned char*) dest_addr;
  unsigned int RCount;

#if ((EPROMSIZE > 2)&&(EPROMSIZE <= 32))
  I2C_TARGET  = EEPROM_ADDR|((src_addr>>7)&0x0E);  //Device_ID_Addr=0XA0
#elif (EPROMSIZE > 512)
  I2C_TARGET  = EEPROM_ADDR|((addr>>15)&0x0E);  //Device_ID_Addr=0XA0
#else
  I2C_TARGET  = EEPROM_ADDR;  //Device_ID_Addr=0XA0
#endif

#if (EPROMSIZE <= 32)
  I2C_Sendbuf[0]  = (src_addr&0xFF);  //24Cxx Memory Address
  I2C_DataTxLen=1;
#else
  I2C_Sendbuf[0]  = ((src_addr>>8)&0xFF);  //24Cxx Memory Address
  I2C_Sendbuf[1]  = (src_addr&0xFF);  //24Cxx Memory Address
  I2C_DataTxLen=2;
#endif
  I2C_Timeout=I2C_Delay;  //HAO=2MHz, wait 5s
  I2C_DataTxIndex=0;
  I2C_DataRxLen=len;
  I2C_DataRxIndex=0;
  I2C_EndFlag=0;
  I2C_RW = I2C_READ;
  DrvI2C_Ctrl(1,0,0,0);  // I2C as master sends START signal
  if(I2C_EndFlag == 0)  // Wait I2C Tx Finish
  {
    while((I2C_Timeout != 0) && (I2C_EndFlag==0) )
    {
	  I2C_Timeout--;
	  asm("nop");
    }
  }
  for(RCount=0 ; RCount < len ; RCount++ )
  {
    *pData=I2C_Recbuf[RCount];
    pData++;
  }
}
